Learn R Programming

distillML (version 0.1.0.13)

set.center.at: Sets a new center in the PDP and ICE plots made by an Interpreter

Description

Method for setting center value for a specific feature

Usage

set.center.at(object, feature, value)

Arguments

object

The Interpreter class that we want to recenter the plots of.

feature

The name of the feature to set grid points for.

value

The new value to use for the plots of the specified feature to be centered at. Must match the type of the feature (a factor level or continuous value in the range of the specified feature).